@@ -3,17 +3,9 @@ use 5.008001;
 use strict;
 use warnings;
 
-use Mojo::Rx::Operators::Creation ':all';
-use Mojo::Rx::Operators::Pipeable ':all';
+our $VERSION = "0.01";
 
-use Exporter 'import';
-our @EXPORT_OK = (
-    @Mojo::Rx::Operators::Creation::EXPORT_OK,
-    @Mojo::Rx::Operators::Pipeable::EXPORT_OK,
-);
-our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.13.0";
 
 1;
 __END__
